@@ -191,11 +191,13 @@ class Rule(Address):
         # check the rule tokens
 
         his_no_pair     = addr.parse(my_last_pos+1)
+        if self.rule_tokens and his_no_pair == (0, 0):
+            return False
+
         my_no_pair      = self.parse(-1)
         my_asst_no_pair = self.parse(-2)
         for rt in self.rule_tokens:
             if (
-                (rt == u'全'         and not his_no_pair > (0, 0)) or
                 (rt == u'單'         and not his_no_pair[0] & 1 == 1) or
                 (rt == u'雙'         and not his_no_pair[0] & 1 == 0) or
                 (rt == u'以上'       and not his_no_pair >= my_no_pair) or
